#ifndef NT2_INCLUDE_FUNCTIONS_ERFC_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ERFC_HPP_INCLUDED

#include <nt2/euler/include/functions/erfc.hpp>

#endif
